.. _utilipy-scripts:

***************************
Scripts (`utilipy.scripts`)
***************************

.. currentmodule:: utilipy.scripts


Reference/API
=============

.. automodapi:: utilipy.scripts
